pytak - Python Team Awareness Kit (PyTAK) Module.
*************************************************

Python Module for creating clients to connect to a Team Awareness Kit (TAK)
Server.


Requirements
============

PyTAK requires libffi/libffi-dev.

Debian & Ubuntu::

  $ sudo apt-get install libffi-dev

RedHat, Fedora, CentOS::

  $ sudo yum install libffi-devel
  # or
  $ sudo dnf install libffi-devel


Installation
============

Option A) Install from the Python Package Index::

    $ pip install pytak


Option B) Install from this source tree::

    $ git clone https://github.com/ampledata/pytak.git
    $ cd pytak/
    $ python setup.py install


Build Status
============

Master:

.. image:: https://travis-ci.com/ampledata/pytak.svg?branch=master
    :target: https://travis-ci.com/ampledata/pytak

Develop:

.. image:: https://travis-ci.com/ampledata/pytak.svg?branch=develop
    :target: https://travis-ci.com/ampledata/pytak


Source
======
Github: https://github.com/ampledata/pytak

Author
======
Greg Albrecht W2GMD oss@undef.net

https://www.orionlabs.io/

Copyright
=========
Copyright 2020 Orion Labs, Inc.

License
=======
Apache License, Version 2.0. See LICENSE for details.
